@@ -2,7 +2,7 @@ package Experian::IDAuth;
 use strict;
 use warnings;
 
-our $VERSION = '2.2';
+our $VERSION = '2.3';
 
 use Locale::Country;
 use Path::Tiny;
@@ -13,9 +13,9 @@ use SOAP::Lite;
 use IO::Socket::SSL 'SSL_VERIFY_NONE';
 
 sub new {
-    my ( $class, %args ) = @_;
+    my ($class, %args) = @_;
     my $obj = bless {}, $class;
-    $obj->set( $obj->defaults, %args );
+    $obj->set($obj->defaults, %args);
     return $obj;
 }
 
@@ -35,7 +35,7 @@ sub defaults {
 }
 
 sub set {
-    my ( $self, %args ) = @_;
+    my ($self, %args) = @_;
     $self->{$_} = $args{$_} for keys %args;
     return $self;
 }
@@ -43,7 +43,7 @@ sub set {
 sub get_result {
     my $self = shift;
     $self->_do_192_authentication || return;
-    for ( $self->{search_option} ) {
+    for ($self->{search_option}) {
         /ProveID_KYC/ && return $self->_get_result_proveid;
         /CheckID/     && return $self->_get_result_checkid;
         die "invalid search_option $_";
@@ -81,8 +81,7 @@ sub save_pdf_result {
             with_fields => {
                 login    => $self->{username},
                 password => $self->{password},
-            }
-        );
+            });
 
         # Download pdf result on given reference number
         $mech->get("$url/archive/index.cfm?event=archive.pdf&id=$our_ref");
@@ -97,7 +96,7 @@ sub save_pdf_result {
     my $folder_pdf = "$self->{folder}/pdf";
 
     # make directory if necessary
-    if ( not -d $folder_pdf ) {
+    if (not -d $folder_pdf) {
         Path::Tiny::path($folder_pdf)->mkpath;
     }
     my $file_pdf = $self->_pdf_report_filename;
@@ -105,7 +104,7 @@ sub save_pdf_result {
 
     # Check if the downloaded file is a pdf.
     my $file_type = qx(file $file_pdf);
-    if ( $file_type !~ /PDF/ ) {
+    if ($file_type !~ /PDF/) {
         warn "discarding downloaded file $file_pdf, not a pdf!";
         unlink $file_pdf;
         return;
@@ -129,7 +128,7 @@ sub has_done_request {
 
 sub get_192_xml_report {
     my $self = shift;
-    return Path::Tiny::path( $self->_xml_report_filename )->slurp;
+    return Path::Tiny::path($self->_xml_report_filename)->slurp;
 }
 
 sub valid_country {
@@ -141,7 +140,7 @@ sub valid_country {
         # in drivers license, Passport MRZ, national ID number
         #qw( ad at au be ca ch cz dk es fi fr gb gg hu ie im it je lu nl no pt se sk us )
         qw ( gb im )
-      )
+        )
     {
         return 1 if $country eq $_;
     }
@@ -152,15 +151,15 @@ sub _build_request {
     my $self = shift;
 
     $self->{request_as_xml} =
-        '<Search>'
-      . ( $self->_build_authentication_tag )
-      . ( $self->_build_country_code_tag || return )
-      . ( $self->_build_person_tag       || return )
-      . ( $self->_build_addresses_tag )
-      . ( $self->_build_telephones_tag )
-      . ( $self->_build_search_reference_tag || return )
-      . ( $self->_build_search_option_tag )
-      . '</Search>';
+          '<Search>'
+        . ($self->_build_authentication_tag)
+        . ($self->_build_country_code_tag || return)
+        . ($self->_build_person_tag       || return)
+        . ($self->_build_addresses_tag)
+        . ($self->_build_telephones_tag)
+        . ($self->_build_search_reference_tag || return)
+        . ($self->_build_search_option_tag)
+        . '</Search>';
 
     return 1;
 }
@@ -172,13 +171,10 @@ sub _send_request {
     my $request = $self->{request_as_xml} || die 'needs request';
 
     # Hide password
-    ( my $request1 = $request ) =~
-      s/\<Password\>.+\<\/Password\>/\<Password\>XXXXXXX<\/Password\>/;
+    (my $request1 = $request) =~ s/\<Password\>.+\<\/Password\>/\<Password\>XXXXXXX<\/Password\>/;
 
     # Create soap object
-    my $soap =
-      SOAP::Lite->readable(1)->uri( $self->{api_uri} )
-      ->proxy( $self->{api_proxy} );
+    my $soap = SOAP::Lite->readable(1)->uri($self->{api_uri})->proxy($self->{api_proxy});
 
     $soap->transport->ssl_opts(
         verify_hostname => 0,
@@ -188,7 +184,7 @@ sub _send_request {
 
     # Do it
     my $som = $soap->search($request);
-    if ( $som->fault ) {
+    if ($som->fault) {
         warn "ERRTEXT: " . $som->fault->faultstring;
         return;
     }
@@ -201,21 +197,16 @@ sub _send_request {
 
 sub _build_authentication_tag {
     my $self = shift;
-    return
-"<Authentication><Username>$self->{username}</Username><Password>$self->{password}</Password></Authentication>";
+    return "<Authentication><Username>$self->{username}</Username><Password>$self->{password}</Password></Authentication>";
 }
 
 sub _build_country_code_tag {
-    my $self              = shift;
-    my $two_digit_country = $self->{residence};
-    my $three_digit_country =
-      uc Locale::Country::country_code2code( $two_digit_country,
-        LOCALE_CODE_ALPHA_2, LOCALE_CODE_ALPHA_3 );
+    my $self                = shift;
+    my $two_digit_country   = $self->{residence};
+    my $three_digit_country = uc Locale::Country::country_code2code($two_digit_country, LOCALE_CODE_ALPHA_2, LOCALE_CODE_ALPHA_3);
 
-    if ( not $three_digit_country ) {
-        warn "Client "
-              . $self->{client_id}
-              . " could not get country from residence [$two_digit_country]";
+    if (not $three_digit_country) {
+        warn "Client " . $self->{client_id} . " could not get country from residence [$two_digit_country]";
         return;
     }
 
@@ -230,34 +221,33 @@ sub _build_person_tag {
         return;
     };
 
-    if ( $dob =~ /^(\d\d\d\d)/ ) {
+    if ($dob =~ /^(\d\d\d\d)/) {
         my $birth_year = $1;
 
         # Check client not older than 100 or less than 18 years old
-        my ( undef, undef, undef, undef, undef, $curyear ) = gmtime(time);
+        my (undef, undef, undef, undef, undef, $curyear) = gmtime(time);
         $curyear += 1900;
         my $maxyear = $curyear - 17;
         my $minyear = $curyear - 100;
 
-        if ( $birth_year > $maxyear or $birth_year < $minyear ) {
+        if ($birth_year > $maxyear or $birth_year < $minyear) {
             return;
         }
-    }
-    else {
+    } else {
         warn "Invalid date of birth [$dob] for " . $self->{client_id};
         return;
     }
 
     return
-        '<Person>'
-      . '<Name><Forename>'
-      . $self->{first_name}
-      . '</Forename>'
-      . '<Surname>'
-      . $self->{last_name}
-      . '</Surname></Name>'
-      . "<DateOfBirth>$dob</DateOfBirth>"
-      . '</Person>';
+          '<Person>'
+        . '<Name><Forename>'
+        . $self->{first_name}
+        . '</Forename>'
+        . '<Surname>'
+        . $self->{last_name}
+        . '</Surname></Name>'
+        . "<DateOfBirth>$dob</DateOfBirth>"
+        . '</Person>';
 
 }
 
@@ -268,8 +258,7 @@ sub _build_addresses_tag {
     my $premise      = $self->{premise} || die 'needs premise';
     my $country_code = $self->_build_country_code_tag;
 
-    return qq(<Addresses><Address Current="1"><Premise>$premise</Premise>)
-      . qq(<Postcode>$postcode</Postcode>$country_code</Address></Addresses>);
+    return qq(<Addresses><Address Current="1"><Premise>$premise</Premise>) . qq(<Postcode>$postcode</Postcode>$country_code</Address></Addresses>);
 }
 
 sub _build_telephones_tag {
@@ -277,32 +266,23 @@ sub _build_telephones_tag {
 
     my $telephone_type = 'U';
     my $number;
-    if ( $self->{phone} =~ /^([\+\d\s]+)/ ) {
+    if ($self->{phone} =~ /^([\+\d\s]+)/) {
         $number = $1;
     }
 
-    return
-        '<Telephones>'
-      . qq(<Telephone Type="$telephone_type">)
-      . "<Number>$number</Number>"
-      . "</Telephone>"
-      . '</Telephones>';
+    return '<Telephones>' . qq(<Telephone Type="$telephone_type">) . "<Number>$number</Number>" . "</Telephone>" . '</Telephones>';
 }
 
 sub _build_search_reference_tag {
     my $self     = shift;
-    my $shortopt = ( $self->{search_option} eq 'ProveID_KYC' ) ? 'PK' : 'C';
+    my $shortopt = ($self->{search_option} eq 'ProveID_KYC') ? 'PK' : 'C';
     my $time     = time();
-    return
-        "<YourReference>${shortopt}_"
-      . $self->{client_id}
-      . "_$time</YourReference>";
+    return "<YourReference>${shortopt}_" . $self->{client_id} . "_$time</YourReference>";
 }
 
 sub _build_search_option_tag {
     my $self = shift;
-    return
-"<SearchOptions><ProductCode>$self->{search_option}</ProductCode></SearchOptions>";
+    return "<SearchOptions><ProductCode>$self->{search_option}</ProductCode></SearchOptions>";
 }
 
 sub _xml_as_hash {
@@ -310,7 +290,7 @@ sub _xml_as_hash {
     my $xml = $self->{result_as_xml} || return;
     return XML::Simple::XMLin(
         $xml,
-        KeyAttr    => { DocumentID => 'type' },
+        KeyAttr    => {DocumentID => 'type'},
         ForceArray => ['DocumentID'],
         ContentKey => '-content',
     );
@@ -327,55 +307,52 @@ sub _get_result_proveid {
         return;
     };
 
-    my ($report_summary_twig) = $twig->get_xpath(
-        '/Search/Result/Summary/ReportSummary/DatablocksSummary');
+    my ($report_summary_twig) = $twig->get_xpath('/Search/Result/Summary/ReportSummary/DatablocksSummary');
 
     return unless $report_summary_twig;
 
     my %report_summary;
-    for my $dblock ( $report_summary_twig->get_xpath('DatablockSummary') ) {
+    for my $dblock ($report_summary_twig->get_xpath('DatablockSummary')) {
         my $name  = $dblock->findvalue('Name');
         my $value = $dblock->findvalue('Decision');
         $report_summary{$name} = $value;
     }
-    my ($kyc_summary) = $twig->get_xpath('/Search/Result/Summary/KYCSummary');
-    my ($credit_reference) =
-      $twig->get_xpath('/Search/Result/CreditReference/CreditReferenceSummary');
+    my ($kyc_summary)      = $twig->get_xpath('/Search/Result/Summary/KYCSummary');
+    my ($credit_reference) = $twig->get_xpath('/Search/Result/CreditReference/CreditReferenceSummary');
 
     return unless $credit_reference and $kyc_summary;
 
-    my $decision = { matches => []};
+    my $decision = {matches => []};
 
     # check if client has died or fraud
     my $cr_deceased = $credit_reference->findvalue('DeceasedMatch') || 0;
     $report_summary{Deceased} ||= 0;
     my $confidence_level = 0;
-    if ( $report_summary{Deceased} ) {
+    if ($report_summary{Deceased}) {
 
         # We only taking Deceased flag in ReportSummary into account
         # if ConfidenceLevel 7 or above
-        my ($deceased_record) =
-          $twig->get_xpath('/Search/Result/Deceased/DeceasedRecord');
+        my ($deceased_record) = $twig->get_xpath('/Search/Result/Deceased/DeceasedRecord');
         $confidence_level = $deceased_record->findvalue('ConfidenceLevel') || 0;
     }
-    if ( ( $report_summary{Deceased} == 1 and $confidence_level > 6 )
-        or $cr_deceased == 1 )
+    if (($report_summary{Deceased} == 1 and $confidence_level > 6)
+        or $cr_deceased == 1)
     {
         $decision->{deceased} = 1;
     }
 
     $report_summary{Fraud} ||= 0;
-    if ( $report_summary{Fraud} == 1 ) {
+    if ($report_summary{Fraud} == 1) {
         $decision->{fraud} = 1;
     }
 
     # check if client is age verified
     my $kyc_dob = $kyc_summary->findvalue('DateOfBirth/Count') || 0;
     my $cr_total = $credit_reference->findvalue('TotalNumberOfVerifications')
-      || 0;
+        || 0;
     $decision->{num_verifications} = $cr_total;
 
-    if ( $kyc_dob or $cr_total ) {
+    if ($kyc_dob or $cr_total) {
         $decision->{age_verified} = 1;
     }
 
@@ -385,17 +362,17 @@ sub _get_result_proveid {
     # Add NoOfCCJ separately since we don't fail that one.
 
     $decision->{CCJ} = 1 if $credit_reference->findvalue('NoOfCCJ');
-    
+
     my @matches =
-      map  { $_->[0] }
-      grep { $_->[1] > 0 }
-      map  { [ $_, $credit_reference->findvalue($_) || 0 ] }
-      qw(BOEMatch PEPMatch OFACMatch CIFASMatch);
+        map  { $_->[0] }
+        grep { $_->[1] > 0 }
+        map  { [$_, $credit_reference->findvalue($_) || 0] } qw(BOEMatch PEPMatch OFACMatch CIFASMatch);
 
     if (@matches) {
-        my @hard_fails = grep { my $f = $_; 
-                                grep { "${f}Match" eq $_ } @matches } 
-                         qw(BOE PEP OFAC CIFAS);
+        my @hard_fails = grep {
+            my $f = $_;
+            grep { "${f}Match" eq $_ } @matches
+        } qw(BOE PEP OFAC CIFAS);
         $decision->{$_} = 1 for @hard_fails;
         $decision->{deny} = 1 if @hard_fails;
 
@@ -403,17 +380,16 @@ sub _get_result_proveid {
     }
 
     # if client is in Directors list, we should not fully authenticate him
-    if ( $report_summary{Directors} ) {
+    if ($report_summary{Directors}) {
         $decision->{director} = 1;
-        $decision->{matches} = [ @{$decision->{matches}}, 'Directors' ];
+        $decision->{matches} = [@{$decision->{matches}}, 'Directors'];
     }
 
     # check if client can be fully authenticated
     my @kyc_two =
-      grep { $_ >= 2 }
-      map { $kyc_summary->findvalue("$_/Count") || 0 }
-      qw(FullNameAndAddress SurnameAndAddress Address DateOfBirth);
-    if ( @kyc_two or $cr_total >= 2 ) {
+        grep { $_ >= 2 }
+        map { $kyc_summary->findvalue("$_/Count") || 0 } qw(FullNameAndAddress SurnameAndAddress Address DateOfBirth);
+    if (@kyc_two or $cr_total >= 2) {
         $decision->{fully_authenticated} = 1;
     }
 
@@ -431,56 +407,31 @@ sub _get_result_checkid {
         return;
     };
 
-    if (
-        (
-            (
-                    $result->{'Result'}->{'ElectoralRoll'}->{'Type'} eq 'Result'
-                and $result->{'Result'}->{'ElectoralRoll'}->{'Summary'}
-                ->{'Decision'} == 1
-            )
+    if ((
+            ($result->{'Result'}->{'ElectoralRoll'}->{'Type'} eq 'Result' and $result->{'Result'}->{'ElectoralRoll'}->{'Summary'}->{'Decision'} == 1)
             or (    $result->{'Result'}->{'Directors'}->{'Type'} eq 'Result'
-                and
-                $result->{'Result'}->{'Directors'}->{'Summary'}->{'Decision'} ==
-                1 )
+                and $result->{'Result'}->{'Directors'}->{'Summary'}->{'Decision'} == 1)
             or (    $result->{'Result'}->{'Telephony'}->{'Type'} eq 'Result'
-                and
-                $result->{'Result'}->{'Telephony'}->{'Summary'}->{'Decision'} ==
-                1 )
-        )
-      )
+                and $result->{'Result'}->{'Telephony'}->{'Summary'}->{'Decision'} == 1)))
     {
 
         # Check Directors DecisionReasons
-        if ( $result->{'Result'}->{'Directors'}->{'Type'} eq 'Result' ) {
-          DIRECTORS_DECISION_REASONS:
-            foreach my $decision_reason (
-                @{
-                    $result->{'Result'}->{'Directors'}->{'Summary'}
-                      ->{'DecisionReasons'}->{'DecisionReason'}
-                }
-              )
-            {
-                if ( $decision_reason->{'Element'} eq
-                    'Director/Person/DateOfBirth'
-                    and $decision_reason->{'Decision'} == 1 )
+        if ($result->{'Result'}->{'Directors'}->{'Type'} eq 'Result') {
+            DIRECTORS_DECISION_REASONS:
+            foreach my $decision_reason (@{$result->{'Result'}->{'Directors'}->{'Summary'}->{'DecisionReasons'}->{'DecisionReason'}}) {
+                if (    $decision_reason->{'Element'} eq 'Director/Person/DateOfBirth'
+                    and $decision_reason->{'Decision'} == 1)
                 {
                     $passed = 1;
                     last DIRECTORS_DECISION_REASONS;
                 }
             }
 
-            if ( not $passed ) {
-              ELECTORALROLL_DECISION_REASONS:
-                foreach my $decision_reason (
-                    @{
-                        $result->{'Result'}->{'ElectoralRoll'}->{'Summary'}
-                          ->{'DecisionReasons'}->{'DecisionReason'}
-                    }
-                  )
-                {
-                    if ( $decision_reason->{'Element'} eq
-                        'ElectoralRollRecord/Person/DateOfBirth'
-                        and $decision_reason->{'Decision'} == 1 )
+            if (not $passed) {
+                ELECTORALROLL_DECISION_REASONS:
+                foreach my $decision_reason (@{$result->{'Result'}->{'ElectoralRoll'}->{'Summary'}->{'DecisionReasons'}->{'DecisionReason'}}) {
+                    if (    $decision_reason->{'Element'} eq 'ElectoralRollRecord/Person/DateOfBirth'
+                        and $decision_reason->{'Decision'} == 1)
                     {
                         $passed = 1;
                         last ELECTORALROLL_DECISION_REASONS;
@@ -503,23 +454,19 @@ sub _do_192_authentication {
     my $residence = $self->{residence};
 
     # check for 192 supported countries
-    unless ( $self->valid_country( $self->{residence} ) ) {
-        warn "Invalid residence: "
-              . $self->{client_id}
-              . ", Residence $residence";
+    unless ($self->valid_country($self->{residence})) {
+        warn "Invalid residence: " . $self->{client_id} . ", Residence $residence";
         return;
     }
 
-    if ( !$force_recheck && $self->has_done_request ) {
+    if (!$force_recheck && $self->has_done_request) {
         $self->{result_as_xml} = $self->get_192_xml_report;
         return 1;
     }
 
     # No previous result so prepare a request
     $self->_build_request
-      || die( "Cannot build xml_request for ["
-          . $self->{client_id}
-          . "/$search_option]" );
+        || die("Cannot build xml_request for [" . $self->{client_id} . "/$search_option]");
 
     # Remove old pdf in case this client has done the 192 pdf request before
     my $file_pdf = $self->_pdf_report_filename;
@@ -533,13 +480,13 @@ sub _do_192_authentication {
 
     # Save xml result
     my $folder_xml = "$self->{folder}/xml";
-    if ( not -d $folder_xml ) {
+    if (not -d $folder_xml) {
         Path::Tiny::path($folder_xml)->mkpath;
     }
     my $file_xml = $self->_xml_report_filename;
-    Path::Tiny::path($file_xml)->spew( $self->{result_as_xml} );
+    Path::Tiny::path($file_xml)->spew($self->{result_as_xml});
 
-    if ( not -e $file_xml ) {
+    if (not -e $file_xml) {
         warn "Couldn't save 192.com xml result for " . $self->{client_id};
         return;
     }
@@ -630,7 +577,7 @@ Then use this module.
         # you can check $prove_id_result->{PEP} etc if you want more detail
     }
     if ($prove_id_result->{fully_authenticated}) {
-        # client successfully authenticated, 
+        # client successfully authenticated,
         # DOES NOT MEAN NO CONCERNS
 
         # check number of credit verifications done
@@ -665,6 +612,30 @@ Then use this module.
 
     Save the Experian credentials as a PDF
 
+=head2 defaults()
+
+    Return default value
+
+=head2 get_192_xml_report()
+
+    Return 192 xml report
+
+=head2 has_done_request()
+
+    Check the request finished or not
+
+=head2 has_downloaded_pdf
+
+    Check the file is downloaded an is a pdf file
+
+=head2 set
+
+    set attributes of object
+
+=head2 valid_country
+
+    Check a country is valid
+
 =head1 AUTHOR
 
 binary.com, C<perl at binary.com>
@@ -717,48 +688,7 @@ L<http://search.cpan.org/dist/Experian-IDAuth/>
     SOAP::Lite
     IO::Socket
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright 2014,2015 binary.com.
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of the the Artistic License (2.0). You may obtain a
-copy of the full license at:
-
-L<http://www.perlfoundation.org/artistic_license_2_0>
-
-Any use, modification, and distribution of the Standard or Modified
-Versions is governed by this Artistic License. By using, modifying or
-distributing the Package, you accept this license. Do not use, modify,
-or distribute the Package, if you do not accept this license.
-
-If your Modified Version has been derived from a Modified Version made
-by someone other than you, you are nevertheless required to ensure that
-your Modified Version complies with the requirements of this license.
-
-This license does not grant you the right to use any trademark, service
-mark, tradename, or logo of the Copyright Holder.
-
-This license includes the non-exclusive, worldwide, free-of-charge
-patent license to make, have made, use, offer to sell, sell, import and
-otherwise transfer the Package with respect to any patent claims
-licensable by the Copyright Holder that are necessarily infringed by the
-Package. If you institute patent litigation (including a cross-claim or
-counterclaim) against any party alleging that the Package constitutes
-direct or contributory patent infringement, then this Artistic License
-to you shall terminate on the date that such litigation is filed.
-
-Disclaimer of Warranty: THE PACKAGE IS PROVIDED BY THE COPYRIGHT HOLDER
-AND CONTRIBUTORS "AS IS' AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES.
-THE IMPLIED WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-PURPOSE, OR NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY
-YOUR LOCAL LAW. UNLESS REQUIRED BY LAW, NO COPYRIGHT HOLDER OR
-CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, OR
-CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE OF THE PACKAGE,
-EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
-
-
 =cut
 
-1; # End of Experian::IDAuth
+1;    # End of Experian::IDAuth
 
